@@ -249,8 +249,8 @@ class UpdateManager(Gtk.Window):
                          "a previous check.")
             return UpdatesAvailable(self, header, desc, need_reboot)
 
-    def start_error(self, is_update_error, header, desc):
-        if is_update_error:
+    def start_error(self, update_and_retry, header, desc):
+        if update_and_retry:
             self._start_pane(UpdateErrorDialog(self, header, desc))
         else:
             self._start_pane(ErrorDialog(self, header, desc))
